@@ -11,7 +11,6 @@
 #include <QObject>
 
 class NotificationHandler;
-class WakeupBackend;
 class WakeupManager;
 
 /**
@@ -71,7 +70,7 @@ private:
     QStringList calendarFileList() const;
 
     QDateTime m_last_checked;
-    NotificationHandler *m_notification_handler;
-    WakeupManager *m_wakeup_manager;
+    NotificationHandler *const m_notification_handler;
+    WakeupManager *const m_wakeup_manager;
 };
 #endif
